prompt: Prompt of an rexpect session

View source: R/prompt.R

promptR Documentation

Prompt of an rexpect session

Description

Functions to get and set the prompt of an rexpect session. Note: this function does not change the prompt of the command that is running.

Usage

prompt(session)

prompt(session) <- value

set_prompt(session, value)

Arguments

session

A rexpect_session.

value

String containing a regular expression that matches all relevant patterns.

Value

String containing a regular expression that matches all relevant patterns.


datascienceworkshops/rexpect documentation built on April 26, 2024, 12:42 p.m.