| rexpect-package | R Documentation |
rexpect allows you to automate interactions with programs that expose a text terminal interface. The API is inspired by the original Expect tool by Don Libes.
Maintainer: Jeroen Janssens jeroen@datascienceworkshops.com (ORCID)
Other contributors:
Data Science Workshops [copyright holder, funder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.