| prompt | R Documentation |
Functions to get and set the prompt of an rexpect session. Note: this function does not change the prompt of the command that is running.
prompt(session)
prompt(session) <- value
set_prompt(session, value)
session |
A rexpect_session. |
value |
String containing a regular expression that matches all relevant patterns. |
String containing a regular expression that matches all relevant patterns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.